import { OnChanges, OnDestroy, SimpleChanges, TemplateRef, ViewContainerRef } from '@angular/core';
import { Observable } from "rxjs";
import * as i0 from "@angular/core";
declare class StateView<T, K = {
    $implicit: T;
}> {
    private _viewContainerRef;
    private _templateRef;
    private _created;
    constructor(_viewContainerRef: ViewContainerRef, _templateRef: TemplateRef<K>);
    create(context?: K): void;
    destroy(): void;
    enforceState(created: boolean): void;
}
interface Views<T> {
    isLoaded?: StateView<T | undefined>;
    isLoadedWithData?: StateView<T>;
    isLoadedWithoutData?: StateView<boolean>;
    isLoading?: StateView<boolean>;
    error?: StateView<Error | unknown>;
}
export declare class AsyncWithStatusDirective<T = unknown> implements OnChanges, OnDestroy {
    private _source$?;
    private _subscription?;
    private _views;
    set asyncWithStatus(source$: Observable<T>);
    ngOnChanges(changes: SimpleChanges): void;
    createView(value: any, viewKey: keyof Views<T>, ...omittedViewKeys: (keyof Views<any>)[]): void;
    ngOnDestroy(): void;
    addView(view: StateView<any>, key: keyof Views<T>): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AsyncWithStatusDirective<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<AsyncWithStatusDirective<any>, "[asyncWithStatus]", never, { "asyncWithStatus": "asyncWithStatus"; }, {}, never>;
}
export declare class IsLoadedDirective {
    private templateRef;
    private viewContainer;
    private asyncWithStatusDirective;
    constructor(templateRef: TemplateRef<any>, viewContainer: ViewContainerRef, asyncWithStatusDirective: AsyncWithStatusDirective);
    static ɵfac: i0.ɵɵFactoryDeclaration<IsLoadedDirective, [null, null, { host: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<IsLoadedDirective, "[isLoaded]", never, {}, {}, never>;
}
export declare class IsLoadedWithDataDirective {
    private templateRef;
    private viewContainer;
    private asyncWithStatusDirective;
    constructor(templateRef: TemplateRef<any>, viewContainer: ViewContainerRef, asyncWithStatusDirective: AsyncWithStatusDirective);
    static ɵfac: i0.ɵɵFactoryDeclaration<IsLoadedWithDataDirective, [null, null, { host: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<IsLoadedWithDataDirective, "[isLoadedWithData]", never, {}, {}, never>;
}
export declare class IsLoadedWithoutDataDirective {
    private templateRef;
    private viewContainer;
    private asyncWithStatusDirective;
    constructor(templateRef: TemplateRef<any>, viewContainer: ViewContainerRef, asyncWithStatusDirective: AsyncWithStatusDirective);
    static ɵfac: i0.ɵɵFactoryDeclaration<IsLoadedWithoutDataDirective, [null, null, { host: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<IsLoadedWithoutDataDirective, "[isLoadedWithoutData]", never, {}, {}, never>;
}
export declare class IsLoadingDirective {
    private templateRef;
    private viewContainer;
    private asyncWithStatusDirective;
    constructor(templateRef: TemplateRef<any>, viewContainer: ViewContainerRef, asyncWithStatusDirective: AsyncWithStatusDirective);
    static ɵfac: i0.ɵɵFactoryDeclaration<IsLoadingDirective, [null, null, { host: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<IsLoadingDirective, "[isLoading]", never, {}, {}, never>;
}
export declare class ErrorDirective {
    private templateRef;
    private viewContainer;
    private asyncWithStatusDirective;
    constructor(templateRef: TemplateRef<any>, viewContainer: ViewContainerRef, asyncWithStatusDirective: AsyncWithStatusDirective);
    static ɵfac: i0.ɵɵFactoryDeclaration<ErrorDirective, [null, null, { host: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ErrorDirective, "[error]", never, {}, {}, never>;
}
export {};
